@@ -38,7 +38,7 @@ from warnings import warn_explicit
 from praw import decorators, errors, helpers
 from praw.settings import CONFIG
 
-__version__ = '2.0.7'
+__version__ = '2.0.8'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -1325,9 +1325,16 @@ class PrivateMessagesMixin(AuthenticatedReddit):
         return self.get_content(self.config['sent'], limit=limit)
 
     @decorators.restrict_access(scope='privatemessages')
-    def get_unread(self, limit=0):
-        """Return a generator for unread messages."""
-        return self.get_content(self.config['unread'], limit=limit)
+    def get_unread(self, limit=0, unset_has_mail=False):
+        """Return a generator for unread messages.
+
+        :param unset_has_mail: When true, clear the has_mail flag (orangered)
+            for the user.
+
+        """
+        params = {'mark': 'true'} if unset_has_mail else None
+        return self.get_content(self.config['unread'], limit=limit,
+                                params=params)
 
     @decorators.restrict_access(scope='privatemessages')
     @decorators.RequireCaptcha
