@@ -150,6 +150,13 @@ class AccessControlTests(unittest.TestCase, BasicHelper):
     def setUp(self):
         self.configure()
 
+    def test_exception_get_flair_list_authenticated(self):
+        self.r.login(self.un, '1111')
+        self.assertTrue(self.r.get_flair_list(self.sr))
+
+    def test_exception_get_flair_list_unauthenticated(self):
+        self.assertTrue(self.r.get_flair_list(self.sr))
+
     def test_login_or_oauth_required_not_logged_in(self):
         self.assertRaises(errors.LoginOrScopeRequired,
                           self.r.add_flair_template, self.sr, 'foo')
@@ -870,19 +877,17 @@ class ModeratorSubredditTest(unittest.TestCase, AuthenticatedHelper):
         other = self.r.get_redditor(self.other_user_name)
         actions = list(self.subreddit.get_mod_log(mod=other.name))
         self.assertTrue(actions)
-        self.assertTrue(all(x.mod_id36 == other.id for x in actions))
-        # TODO: Use the following when reddit PR #631 is added
-        # self.assertTrue(all(x.mod.lower() == other.name.lower()
-        #                    for x in actions))
+        #self.assertTrue(all(x.mod_id36 == other.id for x in actions))
+        self.assertTrue(all(x.mod.lower() == other.name.lower()
+                            for x in actions))
 
     def test_get_mod_log_with_mod_by_redditor_object(self):
         other = self.r.get_redditor(self.other_user_name)
         actions = list(self.subreddit.get_mod_log(mod=other))
         self.assertTrue(actions)
-        self.assertTrue(all(x.mod_id36 == other.id for x in actions))
-        # TODO: Use the following when reddit PR #631 is added
-        # self.assertTrue(all(x.mod.lower() == other.name.lower()
-        #                    for x in actions))
+        #self.assertTrue(all(x.mod_id36 == other.id for x in actions))
+        self.assertTrue(all(x.mod.lower() == other.name.lower()
+                            for x in actions))
 
     def test_get_mod_log_with_action_filter(self):
         actions = list(self.subreddit.get_mod_log(action='removelink'))
@@ -1093,6 +1098,9 @@ class RedditorTest(unittest.TestCase, AuthenticatedHelper):
         self.configure()
         self.other_user = self.r.get_redditor(self.other_user_name)
 
+    def test_duplicate_login(self):
+        self.r.login(self.other_user_name, '1111')
+
     def test_friend(self):
         self.other_user.friend()
 
